import gzip
import io


# Returns a string formatted for human reading, input file_size in bytes
def human_readable_file_size(bytes):
    suffixes = ['Bytes', 'KiloBytes', 'MegaBytes', 'GB', 'TB', 'PB']
    i = 0
    while bytes >= 1024 and i < len(suffixes)-1:
        bytes /= 1024.
        i += 1
    f = ('%.2f' % bytes).rstrip('0').rstrip('.')
    return '%s %s' % (f, suffixes[i])


# Gzip byte data
def gzip(data: bytes) -> bytes:
    out = io.BytesIO()
    with gzip.GzipFile(fileobj=out, mode='wb') as fo:
        fo.write(data)
    bytes_obj = out.getvalue()
    return bytes_obj


# GUnzip byte data
def gunzip(bytes_obj: bytes) -> bytes:
    return gzip.decompress(bytes_obj)


# Tries to figure out the public ip address for the network this PC is on
def get_public_ip():
    ip = '127.0.0.1'
    import socket
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    # Connect to Mindoki.com and ask for the IP that asked (e.g probably our public ip address)
    s.connect(("www.mindoki.com", 80))
    s.sendall(b"GET /ip_responder.php HTTP/1.1\r\nHost: mindoki.com\r\nAccept: text/html\r\n\r\n")
    r = s.recv(4096).decode()

    split = r.split('MINDOKI_IP_RESPONDER:')
    if len(split) == 2:
        ip = split[1]

    return ip
